@@ -41,8 +41,7 @@ simulateResiduals <- function(fittedModel, n = 250, refit = F, integerResponse =
   family = family(fittedModel)
   
   if(is.null(integerResponse)){
-    if (family$family %in% c("binomial", "poisson", "quasibinomial", "quasipoisson", "Negative Binom") | 
-        startsWith(family$family, "Negative Binomial")) integerResponse = T
+    if (family$family %in% c("binomial", "poisson", "quasibinomial", "quasipoisson", "Negative Binom") | grepl("Negative Binomial",family$family) ) integerResponse = T
     else integerResponse = F
   }
   
